@@ -390,7 +390,7 @@ from ae.core import DEBUG_LEVELS, registered_app_names
 from ae.console import ConsoleApp                                                                       # type: ignore
 
 
-__version__ = '0.2.75'
+__version__ = '0.2.76'
 
 
 AppStateType = Dict[str, Any]                   #: app state config variable type
@@ -578,18 +578,6 @@ def flow_popup_class_name(flow_id: str) -> str:
     return flow_class_name(flow_id, 'Popup')
 
 
-def font_min_max_size_from_win(win_width: float, win_height: float) -> Tuple[float, float]:
-    """ calculate optimal range of font size depending on the window/screen resolution.
-
-    :param win_width:       window/screen width in pixels.
-    :param win_height:      window/screen height in pixels.
-    :return:                minimum and maximum font size in pixels.
-    """
-    min_len = min(win_width, win_height)
-    return (min(max(MIN_FONT_SIZE, round(min_len / 48.9)), MAX_FONT_SIZE),
-            min(max(MIN_FONT_SIZE, round(min_len / 24.6)), MAX_FONT_SIZE))
-
-
 def id_of_flow(action: str, obj: str = "", key: str = "") -> str:
     """ create flow id string.
 
@@ -1014,6 +1002,17 @@ class MainAppBase(ConsoleApp, ABC):
             flow_path = self.flow_path
         return flow_action(flow_path_id(flow_path=flow_path, path_index=path_index))
 
+    def font_min_max_size_from_win(self, win_width: float, win_height: float) -> Tuple[float, float]:
+        """ calculate optimal range of font size depending on the window/screen resolution.
+
+        :param win_width:       window/screen width in pixels.
+        :param win_height:      window/screen height in pixels.
+        :return:                minimum and maximum font size in pixels.
+        """
+        min_len = min(win_width, win_height) * self.dpi_factor()
+        return (min(max(MIN_FONT_SIZE, round(min_len / 48.9)), MAX_FONT_SIZE),
+                min(max(MIN_FONT_SIZE, round(min_len / 24.6)), MAX_FONT_SIZE))
+
     def global_variables(self, **patches) -> Dict[str, Any]:
         """ determine generic/most-needed global variables to evaluate expressions/macros.
 
@@ -1406,7 +1405,7 @@ class MainAppBase(ConsoleApp, ABC):
         win_width, win_height = app_states.get('win_rectangle', (0, 0, 1920, 1080))[2:]
         if not MIN_FONT_SIZE <= font_size <= MAX_FONT_SIZE:   # adopt device scaling on very first app start
             if font_size == -1.0:
-                min_f, max_f = font_min_max_size_from_win(win_width, win_height)
+                min_f, max_f = self.font_min_max_size_from_win(win_width, win_height)
                 font_size = min_f + (max_f - min_f) / 3.0
             elif font_size < 0.0:
                 font_size = self.dpi_factor() * -font_size
@@ -1526,7 +1525,7 @@ class MainAppBase(ConsoleApp, ABC):
         app.landscape = win_width >= win_height                 # update landscape flag
 
         font_size = self.font_size
-        min_f, max_f = font_min_max_size_from_win(win_width, win_height)
+        min_f, max_f = self.font_min_max_size_from_win(win_width, win_height)
         if not min_f <= font_size <= max_f:
             self.change_app_state('font_size', min(max(min_f, font_size), max_f))
         app.max_font_size = max_f                               # update dynamic min/max font size
